@@ -6,6 +6,8 @@ pub enum Error {
     NotFound(String),
     #[error("{0} is invalid")]
     Invalid(String),
+    #[error("{0}")]
+    Forbidden(String),
 }
 
 impl Error {
